PacketRef

Struct PacketRef 

pub struct PacketRef<'a> { /* private fields */ }
A generic packet, not parsed as any particular payload type.

This only interprets the leading four bytes:

 0                   1                   2                   3
 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1
+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
|V=2|P|         |   PT          |             length            |
+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+

Implementations

Source

impl<'a> PacketRef<'a>

pub fn parse(buf: &'a [u8]) -> Result<(Self, &'a [u8]), String>

Parses a buffer into this packet and rest, doing only basic validation of the version, padding, and length.

pub fn payload_type(&self) -> u8

Returns the uninterpreted payload type of this RTCP packet.

pub fn as_typed(self) -> Result<Option<TypedPacketRef<'a>>, String>

Parses to a TypedPacketRef if the payload type is supported.

pub fn as_sender_report(self) -> Result<Option<SenderReportRef<'a>>, String>

Parses as a sender report, if the type matches.

pub fn has_padding(&self) -> bool

Returns true iff this packet has padding.

pub fn count(&self) -> u8

Returns the low 5 bits of the first octet, which is typically a count or subtype.

pub fn raw(&self) -> &[u8]

Returns the full raw data, including headers.